(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: options.mli,v 1.33 2014-02-26 00:12:42 fclement Exp $ *)

open Segmentation_types;;

(* Codomain implementation.*)

type option_codomain_implementation =
  | Option_Tuple_Cod
  | Option_Vector_Cod
;;

val get_option_codomain_implementation :
  unit -> option_codomain_implementation
;;

(* Dimension.*)

type option_dimension = int;;

val phase_dimension : Ucommand_option.phase_name;;
val get_option_dimension : unit -> option_dimension;;

(* Dimension management. *)

type option_dimension_management =
  | Option_Vector
  | Option_Best_component_only
  | Option_Best_component_for_each
  | Option_Combine_best_components
;;

val get_option_dimension_management : unit -> option_dimension_management;;

(* Cutting strategy. *)

type option_cutting_strategy =
  | Option_Best_in_a_family
  | Option_Overall_best

and option_number_of_cuts = int

and option_basic_cutting_family =
  | Option_Horizontal
  | Option_Vertical

and option_basic_cutting_families = option_basic_cutting_family list
;;

val get_option_cutting_strategy : unit -> option_cutting_strategy;;
val get_option_number_of_cuts : unit -> option_number_of_cuts;;
val get_option_basic_cutting_families : unit -> option_basic_cutting_families;;

(* Stopping criterion. *)

type option_max_iteration = int
and option_min_best_scalar_indicator = float
and option_min_scalar_relative_error = float
;;

val get_option_max_iteration : unit -> option_max_iteration;;
val get_option_min_best_scalar_indicator :
  unit -> option_min_best_scalar_indicator
;;
val get_option_min_scalar_relative_error :
  unit -> option_min_scalar_relative_error
;;

(* Program configuration. *)

type option_out_formatter =
  | Option_Std_out
  | Option_Std_err
  | Option_Out_file of Ufilename.t
;;

val get_option_out_formatter : unit -> option_out_formatter;;

type option_report_allocated_memory = bool;;

val get_option_report_allocated_memory :
  unit -> option_report_allocated_memory
;;

type option_incremental_mode = bool;;

val get_option_incremental_mode : unit -> option_incremental_mode;;

type option_graphics_mode =
  | Option_No_graphics
  | Option_Minimal_graphics
  | Option_Parameter_graphics
  | Option_Compound_graphics
  | Option_Full_graphics
;;

val get_option_graphics_mode : unit -> option_graphics_mode;;

type option_graphics_window_min_width = int
and option_graphics_window_min_height = int
and option_graphics_window_max_width = int
and option_graphics_window_max_height = int
;;

val get_option_graphics_window_min_width :
  unit -> option_graphics_window_min_width
;;
val get_option_graphics_window_min_height :
  unit -> option_graphics_window_min_height
;;
val get_option_graphics_window_max_width :
  unit -> option_graphics_window_max_width
;;
val get_option_graphics_window_max_height :
  unit -> option_graphics_window_max_height
;;

type option_graphics_gradient_threshold = int;;

val get_option_graphics_gradient_threshold :
  unit -> option_graphics_gradient_threshold
;;

(* Initial and final images. *)

type argument_initial_image = image
and argument_initial_image_width = width
and argument_initial_image_height = height
;;

val get_argument_initial_image : unit -> argument_initial_image;;
val get_argument_initial_image_width : unit -> argument_initial_image_width;;
val get_argument_initial_image_height : unit -> argument_initial_image_height;;

type option_final_image_file_name = Ufilename.t;;

val get_option_final_image_file_name : unit -> option_final_image_file_name;;

(* Report/debug flags and error messages. *)

val printing_facilities : Udebug.printing_facilities;;
